[PATCH] Comment translation german-english in sw/source/ui/table/

2013-03-09 Thread Matthias Freund (via Code Review)
Hi,

I have submitted a patch for review:

https://gerrit.libreoffice.org/2625

To pull it, you can do:

git pull ssh://gerrit.libreoffice.org:29418/core refs/changes/25/2625/1

Comment translation german-english in sw/source/ui/table/

Translations and cleanups...

Change-Id: I486a0caac11786c8edb4dd8b6099771db075a336
---
M sw/source/ui/table/convert.cxx
M sw/source/ui/table/instable.cxx
M sw/source/ui/table/swtablerep.cxx
M sw/source/ui/table/tabledlg.cxx
M sw/source/ui/table/tablemgr.cxx
M sw/source/ui/table/tablepg.hxx
M sw/source/ui/table/tautofmt.cxx
7 files changed, 58 insertions(+), 156 deletions(-)



diff --git a/sw/source/ui/table/convert.cxx b/sw/source/ui/table/convert.cxx
index 93e3624..d2ea4ca 100644
--- a/sw/source/ui/table/convert.cxx
+++ b/sw/source/ui/table/convert.cxx
@@ -147,7 +147,7 @@
 }
 else
 {
-//Einfuege-Optionen verstecken
+//hide insert options
 mpOptions-Hide();
 }
 mpKeepColumn-SaveValue();
diff --git a/sw/source/ui/table/instable.cxx b/sw/source/ui/table/instable.cxx
index 466acbc..440323b 100644
--- a/sw/source/ui/table/instable.cxx
+++ b/sw/source/ui/table/instable.cxx
@@ -70,9 +70,6 @@
 rInsTblOpts.mnInsMode = nInsMode;
 }
 
-// CTOR / DTOR ---
-
-
 SwInsTableDlg::SwInsTableDlg( SwView rView )
 : SfxModalDialog(rView.GetWindow(), InsertTableDialog, 
modules/swriter/ui/inserttable.ui)
 , pShell(rView.GetWrtShell())
diff --git a/sw/source/ui/table/swtablerep.cxx 
b/sw/source/ui/table/swtablerep.cxx
index 96944b2..88d86a8 100644
--- a/sw/source/ui/table/swtablerep.cxx
+++ b/sw/source/ui/table/swtablerep.cxx
@@ -110,8 +110,8 @@
 rTabCols.SetLeft(nLeft);
 if(bSingleLine)
 {
-// die unsichtbaren Trenner werden aus den alten TabCols genommen
-// die sichtbaren kommen aus pTColumns
+// The invisible separators are taken from the old TabCols,
+// the visible coming from pTColumns.
 TColumn*pOldTColumns = new TColumn[nAllCols + 1];
 SwTwips nStart = 0,
 nEnd;
@@ -150,7 +150,7 @@
 break;
 }
 bFirst = false;
-// sie muessen sortiert eingefuegt werden
+// They have to be inserted sorted.
 bOld = nOld  nNew;
 nPos = sal_uInt16(bOld ? nOld : nNew);
 rTabCols[i] = nPos + nLeft;
@@ -172,7 +172,7 @@
 }
 }
 
-// Rundungsfehler abfangen
+// intercept rounding errors
 if(Abs((long)nOldLeft - (long)rTabCols.GetLeft())  3)
 rTabCols.SetLeft(nOldLeft);
 
diff --git a/sw/source/ui/table/tabledlg.cxx b/sw/source/ui/table/tabledlg.cxx
index 3efc619..9311d95 100644
--- a/sw/source/ui/table/tabledlg.cxx
+++ b/sw/source/ui/table/tabledlg.cxx
@@ -140,8 +140,6 @@
 m_pRelWidthCB-SetClickHdl(LINK( this, SwFormatTablePage, RelWidthClickHdl 
));
 }
 
-/**/
-
 IMPL_LINK( SwFormatTablePage, RelWidthClickHdl, CheckBox *, pBtn )
 {
 OSL_ENSURE(pTblData, table data not available?);
@@ -157,7 +155,7 @@
 m_aWidthMF.SetRefValue(pTblData-GetSpace());
 m_aLeftMF.SetRefValue(pTblData-GetSpace());
 m_aRightMF.SetRefValue(pTblData-GetSpace());
-m_aLeftMF.SetMetricFieldMin(0); // wird vom Percentfield ueberschrieben
+m_aLeftMF.SetMetricFieldMin(0); // will be overwritten by the 
Percentfield
 m_aRightMF.SetMetricFieldMin(0); // --
 m_aLeftMF.SetMetricFieldMax(99); //
 m_aRightMF.SetMetricFieldMax(99); //
@@ -165,7 +163,7 @@
 m_aRightMF.SetPrcntValue(m_aRightMF.NormalizePercent(nRight ), 
FUNIT_TWIP );
 }
 else
-ModifyHdl(m_aLeftMF.get());// Werte wieder korrigieren
+ModifyHdl(m_aLeftMF.get());// correct values again
 
 if(m_pFreeBtn-IsChecked())
 {
@@ -234,8 +232,8 @@
 
 if(bFull  bRestore)
 {
-// nachdem auf autom. geschaltet wurde, wurde die Breite gemerkt,
-// um sie beim Zurueckschalten restaurieren zu koennen
+// After being switched on automatically, the width was pinned
+// in order to restore the width while switching back to.
 bFull = sal_False;
 m_aWidthMF.SetPrcntValue(m_aWidthMF.NormalizePercent(nSaveWidth ), 
FUNIT_TWIP );
 }
@@ -244,7 +242,6 @@
 return 0;
 }
 
-/*--*/
 void SwFormatTablePage::RightModify()
 {
 if(m_pFreeBtn-IsChecked())
@@ -286,13 +283,13 @@
 if( nCurWidth  MINLAY )
 nCurWidth = MINLAY;
 nDiff = nRight + nLeft + nCurWidth - pTblData-GetSpace() ;
-//rechtsbuendig nur linken Rand veraendern
+//only change the left boundary right aligned
 if(m_pRightBtn-IsChecked())
 nLeft -= nDiff;
-//linksbuendig nur rechten Rand veraendern
+//only change the right 

[PATCH] Comment translation german-english sw/source/ui/uno/

2013-03-03 Thread Matthias Freund (via Code Review)
Hi,

I have submitted a patch for review:

https://gerrit.libreoffice.org/2530

To pull it, you can do:

git pull ssh://gerrit.libreoffice.org:29418/core refs/changes/30/2530/1

Comment translation german-english sw/source/ui/uno/

Change-Id: I350aa56bd27ef55a44d5a7140e78fa36b350b302
---
M sw/source/ui/uno/unotxdoc.cxx
M sw/source/ui/uno/unotxvw.cxx
2 files changed, 35 insertions(+), 42 deletions(-)



diff --git a/sw/source/core/docnode/ndtbl.cxx b/sw/source/core/docnode/ndtbl.cxx
index 775359a..9e296eb 100644
--- a/sw/source/core/docnode/ndtbl.cxx
+++ b/sw/source/core/docnode/ndtbl.cxx
@@ -333,8 +333,8 @@
sal_Bool bCalledFromShell,
sal_Bool bNewModel )
 {
-OSL_ENSURE( nRows, Tabelle ohne Zeile? );
-OSL_ENSURE( nCols, Tabelle ohne Spalten? );
+OSL_ENSURE( nRows, Table without line? );
+OSL_ENSURE( nCols, Table without rows? );
 
 {
 // Do not copy into Footnotes!
@@ -1398,7 +1398,7 @@
 aCellNodeIdx = SwNodeIndex( 
*aCellNodeIdx.GetNode().EndOfSectionNode() );
 }
 
-// Section der Box zuweisen
+// assign Section to the Box
 pBox = new SwTableBox( pBoxFmt, *pSttNd, pLine );
 pLine-GetTabBoxes().insert( pLine-GetTabBoxes().begin() + 
nBoxes++, pBox );
 }
@@ -3086,7 +3086,7 @@
 }
 }
 
-// bedingte Vorlage beachten
+// note conditional template
 pBox-GetSttNd()-CheckSectionCondColl();
 }
 }
diff --git a/sw/source/core/edit/acorrect.cxx b/sw/source/core/edit/acorrect.cxx
index b1df33b..0242a54 100644
--- a/sw/source/core/edit/acorrect.cxx
+++ b/sw/source/core/edit/acorrect.cxx
@@ -64,7 +64,7 @@
 }
 _PaMIntoCrsrShellRing::~_PaMIntoCrsrShellRing()
 {
-// und den Pam wieder herausnehmen:
+// and take out the Pam again:
 RemoveFromRing( rDelPam, pPrevDelPam );
 RemoveFromRing( rCrsr, pPrevCrsr );
 }
@@ -102,8 +102,8 @@
 SwDoc* pDoc = rEditSh.GetDoc();
 if( pDoc-IsAutoFmtRedline() )
 {
-// damit der DelPam auch verschoben wird, in den Shell-Cursr-Ring
-// mit aufnehmen !!
+// so that also the DelPam be moved,  include it in the
+// Shell-Cursr-Ring !!
 _PaMIntoCrsrShellRing aTmp( rEditSh, rCrsr, rDelPam );
 pDoc-DeleteAndJoin( rDelPam );
 }
@@ -181,7 +181,7 @@
 
 if( pDoc-IsAutoFmtRedline() )
 {
-if( nPos == pNd-GetTxt().Len() )   // am Ende erfolgt ein 
Insert
+if( nPos == pNd-GetTxt().Len() )   // at the End an Insert 
takes place
 {
 pDoc-InsertString( *pPam, rTxt );
 }
@@ -271,13 +271,13 @@
 return sal_True;
 }
 
-// returne den Text eines vorherigen Absatzes.
-// Dieser darf nicht leer sein!
-// Gibt es diesen nicht oder gibt es davor nur Leere, dann returne 0
-// Das Flag gibt an:
-//  sal_True: den, vor der normalen Einfuegeposition (sal_True)
-//  sal_False: den, in den das korrigierte Wort eingfuegt wurde.
-//  (Muss nicht der gleiche Absatz sein)
+// Return the text of a previous paragraph
+// This must not be empty!
+// Does this not exists or there are only blankness, then return 0
+// The Flag specifies:
+// sal_True: that, before the normal insert position
+//sal_False: that, in which the corrected word was inserted.
+//  (Doesn't need to be the same paragraph)
 const String* SwAutoCorrDoc::GetPrevPara( sal_Bool bAtNormalPos )
 {
 const String* pStr = 0;
@@ -309,10 +309,10 @@
 if( bUndoIdInitialized )
 bUndoIdInitialized = true;
 
-// Absatz-Anfang oder ein Blank gefunden, suche nach dem Wort
-// Kuerzel im Auto
+// Found a beginning of a paragraph or a Blank, suche nach dem Wort
+// search for the word Kuerzel (Shortcut) in the Auto
 SwTxtNode* pTxtNd = rCrsr.GetNode()-GetTxtNode();
-OSL_ENSURE( pTxtNd, wo ist denn der TextNode? );
+OSL_ENSURE( pTxtNd, where is the TextNode? );
 
 sal_Bool bRet = sal_False;
 if( nEndPos == rSttPos )
@@ -322,7 +322,7 @@
 if(LANGUAGE_SYSTEM == eLang)
 eLang = GetAppLanguage();
 
-//JP 22.04.99: Bug 63883 - Sonderbehandlung fuer Punkte.
+//JP 22.04.99: Bug 63883 - Special treatment for dots.
 bool bLastCharIsPoint = nEndPos  pTxtNd-GetTxt().Len() 
 '.' == pTxtNd-GetTxt().GetChar( nEndPos );
 
@@ -336,7 +336,7 @@
 
 if( pFnd-IsTextOnly() )
 {
-//JP 22.04.99: Bug 63883 - Sonderbehandlung fuer Punkte.
+//JP 22.04.99: Bug 63883 - Special treatment for dots.
 if( 

[PATCH] Comment translation german-english

2013-02-15 Thread Matthias Freund (via Code Review)
Hi,

I have submitted a patch for review:

https://gerrit.libreoffice.org/2171

To pull it, you can do:

git pull ssh://gerrit.libreoffice.org:29418/core refs/changes/71/2171/1

Comment translation german-english

Change-Id: Ia5c5d1d8b539ffb4286232177c12b294b0f60706
---
M sw/source/core/draw/dcontact.cxx
M sw/source/core/draw/drawdoc.cxx
M sw/source/ui/utlui/numfmtlb.cxx
3 files changed, 29 insertions(+), 91 deletions(-)



diff --git a/sw/source/core/draw/dcontact.cxx b/sw/source/core/draw/dcontact.cxx
index ed69adb..8d38294 100644
--- a/sw/source/core/draw/dcontact.cxx
+++ b/sw/source/core/draw/dcontact.cxx
@@ -173,11 +173,7 @@
  || SDRTEXTANI_ALTERNATE == eTKind || SDRTEXTANI_SLIDE == eTKind );
 }
 
-/*
-|*
-|*  SwContact, Ctor and Dtor
-|*
-|*/
+// SwContact
 
 SwContact::SwContact( SwFrmFmt *pToRegisterIn ) :
 SwClient( pToRegisterIn ),
@@ -200,7 +196,6 @@
 }
 
 /** method to move drawing object to corresponding visible layer
-
 @author OD
 */
 void SwContact::MoveObjToVisibleLayer( SdrObject* _pDrawObj )
@@ -234,9 +229,7 @@
 }
 
 /** method to move drawing object to corresponding invisible layer
-
 OD 21.08.2003 #i18447#
-
 @author OD
 */
 void SwContact::MoveObjToInvisibleLayer( SdrObject* _pDrawObj )
@@ -263,11 +256,9 @@
 }
 
 /** method to move object to visible/invisible layer
-
 OD 21.08.2003 #i18447#
 implementation for the public method MoveObjToVisibleLayer(..)
 and MoveObjToInvisibleLayer(..)
-
 @author OD
 */
 void SwContact::_MoveObjToLayer( const bool _bToVisible,
@@ -359,7 +350,6 @@
 }
 }
 
-// -
 // some virtual helper methods for information
 // about the object (Writer fly frame resp. drawing object)
 
@@ -368,10 +358,9 @@
 return GetCntntAnchor().nContent;
 }
 
-/** get minimum order number of anchored objects handled by with contact
+// get minimum order number of anchored objects handled by with contact
+// @author
 
-@author
-*/
 sal_uInt32 SwContact::GetMinOrdNum() const
 {
 sal_uInt32 nMinOrdNum( SAL_MAX_UINT32 );
@@ -421,13 +410,8 @@
 
 return nMaxOrdNum;
 }
-// -
 
-/*
-|*
-|*  SwFlyDrawContact, Ctor und Dtor
-|*
-|*/
+// SwFlyDrawContact
 
 SwFlyDrawContact::SwFlyDrawContact( SwFlyFrmFmt *pToRegisterIn, SdrModel * ) :
 SwContact( pToRegisterIn )
@@ -506,11 +490,7 @@
 mpMasterObj = static_castSwFlyDrawObj *(_pNewMaster);
 }
 
-/*
-|*
-|*  SwFlyDrawContact::Modify()
-|*
-|*/
+// SwFlyDrawContact::Modify()
 
 void SwFlyDrawContact::Modify( const SfxPoolItem*, const SfxPoolItem * )
 {
@@ -598,11 +578,8 @@
 SwFlyFrm::GetAnchoredObjects( _roAnchoredObjs, *pFmt );
 }
 
-/*
-|*
-|*  SwDrawContact, Ctor+Dtor
-|*
-|*/
+// SwDrawContact
+
 bool CheckControlLayer( const SdrObject *pObj )
 {
 if ( FmFormInventor == pObj-GetObjInventor() )
@@ -1010,11 +987,7 @@
 return pRetDrawObj;
 }
 
-/*
-|*
-|*  SwDrawContact::Changed
-|*
-|*/
+// SwDrawContact::Changed
 
 void SwDrawContact::NotifyBackgrdOfAllVirtObjs( const Rectangle* pOldBoundRect 
)
 {
@@ -1469,11 +1442,7 @@
 }
 }
 
-/*
-|*
-|*  SwDrawContact::Modify()
-|*
-|*/
+// SwDrawContact::Modify()
 
 void SwDrawContact::Modify( const SfxPoolItem* pOld, const SfxPoolItem *pNew )
 {
@@ -1624,11 +1593,7 @@
 }
 }
 
-/*
-|*
-|*  SwDrawContact::DisconnectFromLayout()
-|*
-|*/
+// SwDrawContact::DisconnectFromLayout()
 
 void SwDrawContact::DisconnectFromLayout( bool _bMoveMasterToInvisibleLayer )
 {
@@ -1740,11 +1705,8 @@
 }
 }
 
-/*
-|*
-|*  SwDrawContact::ConnectToLayout()
-|*
-|*/
+// SwDrawContact::ConnectToLayout()
+
 static SwTxtFrm* lcl_GetFlyInCntntAnchor( SwTxtFrm* _pProposedAnchorFrm,
const xub_StrLen _nTxtOfs )
 {
@@ -1951,11 

[PATCH] Comment translation german - english - redo of writer.cxx

2013-02-14 Thread Matthias Freund (via Code Review)
Hi,

I have submitted a patch for review:

https://gerrit.libreoffice.org/2140

To pull it, you can do:

git pull ssh://gerrit.libreoffice.org:29418/core refs/changes/40/2140/1

Comment translation german - english - redo of writer.cxx

Change-Id: Idf885dc8d47077800bdc648072aa45eb46c9a286
---
M sw/source/filter/writer/writer.cxx
1 file changed, 34 insertions(+), 34 deletions(-)



diff --git a/sw/source/filter/writer/writer.cxx 
b/sw/source/filter/writer/writer.cxx
index 21dd1bc..bd1de3f 100644
--- a/sw/source/filter/writer/writer.cxx
+++ b/sw/source/filter/writer/writer.cxx
@@ -37,7 +37,7 @@
 using namespace ::com::sun::star;
 
 
-// Stringbuffer fuer die umgewandelten Zahlen
+// Stringbuffer for the converted numbers
 static sal_Char aNToABuf[] = 0;
 #define NTOABUFLEN (sizeof(aNToABuf))
 
@@ -91,16 +91,16 @@
 }
 
 /*
- * Dieses Modul ist die Zentrale-Sammelstelle fuer alle Write-Filter
- * und ist eine DLL !
+ * This module is the central collection point for all writer-filters
+ * and is a DLL !
  *
- * Damit der Writer mit den unterschiedlichen Writern arbeiten kann,
- * muessen fuer diese die Ausgabe-Funktionen der Inhalts tragenden
- * Objecte auf die verschiedenen Ausgabe-Funktionen gemappt werden.
+ * So that the Writer can work with different writers, the output-functions
+ * of the content carrying objects have to be mapped to the various
+ * output-functions.
  *
- * Dazu kann fuer jedes Object ueber den Which-Wert in einen Tabelle ge-
- * griffen werden, um seine Ausgabe-Funktion zu erfragen.
- * Diese Funktionen stehen in den entsprechenden Writer-DLL's.
+ * For that, to inquire its output function, every object can be gripped
+ * via the which-value in a table.
+ * These functions are available in the corresponding Writer-DLL's.
  */
 
 Writer::Writer()
@@ -151,11 +151,11 @@
 {
 if( (*ppPam)-GetNext() == pOrigPam )
 {
-*ppPam = pOrigPam;  // wieder auf den Anfangs-Pam setzen
-return sal_False;   // Ende vom Ring
+*ppPam = pOrigPam;  // set back to the beginning pam
+return sal_False;   // end of the ring
 }
 
-// ansonsten kopiere den die Werte aus dem naechsten Pam
+// otherwise copy the next value from the next Pam
 *ppPam = ((SwPaM*)(*ppPam)-GetNext() );
 
 *pCurPam-GetPoint() = *(*ppPam)-Start();
@@ -164,7 +164,7 @@
 return sal_True;
 }
 
-// suche die naechste Bookmark-Position aus der Bookmark-Tabelle
+// search the next Bookmark-Position from the Bookmark-Table
 
 sal_Int32 Writer::FindPos_Bkmk(const SwPosition rPos) const
 {
@@ -189,7 +189,7 @@
 SwCntntNode* pCNode = aStt.GetNode().GetCntntNode();
 if( !pCNode  0 == ( pCNode = pNds-GoNext( aStt )) )
 {
-OSL_FAIL( An StartPos kein ContentNode mehr );
+OSL_FAIL( No more ContentNode at StartPos );
 }
 
 SwPaM* pNew = new SwPaM( aStt );
@@ -198,7 +198,7 @@
 if( 0 == (pCNode = aStt.GetNode().GetCntntNode()) 
 0 == (pCNode = pNds-GoPrevious( aStt )) )
 {
-OSL_FAIL( An StartPos kein ContentNode mehr );
+OSL_FAIL( No more ContentNode at StartPos );
 }
 pCNode-MakeEndIndex( pNew-GetPoint()-nContent );
 pNew-GetPoint()-nNode = aStt;
@@ -207,7 +207,7 @@
 
 /
 
-// Stream-spezifisches
+// Stream-specific
 SvStream Writer::Strm()
 {
 OSL_ENSURE( m_pImpl-m_pStream, Oh-oh. Writer with no Stream! );
@@ -219,7 +219,7 @@
 
 SvStream Writer::OutLong( SvStream rStrm, long nVal )
 {
-// Pointer an das Bufferende setzen
+// Set the Pointer at the end of the buffer
 sal_Char* pStr = aNToABuf + (NTOABUFLEN-1);
 
 int bNeg = nVal  0;
@@ -231,7 +231,7 @@
 nVal /= 10;
 } while( nVal );
 
-// Ist Zahl negativ, dann noch -
+// is the number negative, then in addition -
 if( bNeg )
 *(--pStr) = '-';
 
@@ -240,7 +240,7 @@
 
 SvStream Writer::OutULong( SvStream rStrm, sal_uLong nVal )
 {
-// Pointer an das Bufferende setzen
+// Set the Pointer at the end of the buffer
 sal_Char* pStr = aNToABuf + (NTOABUFLEN-1);
 
 do {
@@ -266,9 +266,9 @@
 pOrigFileName = pFName;
 m_pImpl-m_pStream = rStrm;
 
-// PaM kopieren, damit er veraendert werden kann
+// Copy PaM, so that it can be modified
 pCurPam = new SwPaM( *rPaM.End(), *rPaM.Start() );
-// zum Vergleich auf den akt. Pam sichern
+// for comparison secure to the current Pam
 pOrigPam = rPaM;
 
 sal_uLong nRet = WriteStream();
@@ -287,13 +287,13 @@
 
 sal_uLong Writer::Write( SwPaM /*rPam*/, SvStorage, const String* )
 {
-OSL_ENSURE( !this, Schreiben in Storages auf einem Stream? );
+OSL_ENSURE( !this, Write in Storages on a stream? );
 return ERR_SWG_WRITE_ERROR;
 }
 
 sal_uLong Writer::Write( SwPaM, const uno::Reference  embed::XStorage , 
const String*, SfxMedium* )
 {
-OSL_ENSURE( !this, Schreiben in Storages 

[PATCH] Comment translation german - english - redo of 5 files

2013-02-14 Thread Matthias Freund (via Code Review)
Hi,

I have submitted a patch for review:

https://gerrit.libreoffice.org/2143

To pull it, you can do:

git pull ssh://gerrit.libreoffice.org:29418/core refs/changes/43/2143/1

Comment translation german - english - redo of 5 files

I have send it  again and abandon the old changes. Hope this is correct?
:-D

Change-Id: Ib7668f30d4c813ce656e9d8d5fcc0060d1a6aff5
---
M sw/source/core/docnode/ndnum.cxx
M sw/source/core/docnode/ndsect.cxx
M sw/source/core/draw/dcontact.cxx
M sw/source/core/draw/dpage.cxx
M sw/source/core/draw/drawdoc.cxx
5 files changed, 34 insertions(+), 34 deletions(-)



diff --git a/sw/source/core/docnode/ndnum.cxx b/sw/source/core/docnode/ndnum.cxx
index 86d3e44..91b861ec 100644
--- a/sw/source/core/docnode/ndnum.cxx
+++ b/sw/source/core/docnode/ndnum.cxx
@@ -21,7 +21,7 @@
 #include doc.hxx
 #include pam.hxx
 #include ndtxt.hxx
-#include fldbas.hxx   // UpdateFlds der KapitelNummerierung
+#include fldbas.hxx   // UpdateFlds of the chapter numbering
 #include docary.hxx
 
 bool CompareSwOutlineNodes::operator()( SwNode* const lhs, SwNode* const 
rhs) const
@@ -67,20 +67,20 @@
 
 pTxtNd-UpdateOutlineState();
 
-// die Gliederungs-Felder Updaten
+// update the structure fields
 GetDoc()-GetSysFldType( RES_CHAPTERFLD )-UpdateFlds();
 }
 }
 
 void SwNodes::UpdtOutlineIdx( const SwNode rNd )
 {
-if( pOutlineNds-empty() ) // keine OutlineNodes vorhanden ?
+if( pOutlineNds-empty() ) // no OutlineNodes present ?
 return;
 
 const SwNodePtr pSrch = (SwNodePtr)rNd;
 sal_uInt16 nPos;
 pOutlineNds-Seek_Entry( pSrch, nPos );
-if( nPos == pOutlineNds-size() )  // keine zum Updaten vorhanden ?
+if( nPos == pOutlineNds-size() )  // none present for updating ?
 return;
 
 if( nPos )
diff --git a/sw/source/core/docnode/ndsect.cxx 
b/sw/source/core/docnode/ndsect.cxx
index 42983c9..d798fa1 100644
--- a/sw/source/core/docnode/ndsect.cxx
+++ b/sw/source/core/docnode/ndsect.cxx
@@ -1227,7 +1227,7 @@
 // In which array am I: Nodes, UndoNodes?
 const SwNodes rNds = GetNodes();
 
-// Copy the das SectionFrmFmt
+// Copy the SectionFrmFmt
 SwSectionFmt* pSectFmt = pDoc-MakeSectionFmt( 0 );
 pSectFmt-CopyAttrs( *GetSection().GetFmt() );
 
diff --git a/sw/source/core/draw/dcontact.cxx b/sw/source/core/draw/dcontact.cxx
index 3449521..ed69adb 100644
--- a/sw/source/core/draw/dcontact.cxx
+++ b/sw/source/core/draw/dcontact.cxx
@@ -89,11 +89,11 @@
 }
 
 
-//Der Umgekehrte Weg: Sucht das Format zum angegebenen Objekt.
-//Wenn das Object ein SwVirtFlyDrawObj ist so wird das Format von
-//selbigem besorgt.
-//Anderfalls ist es eben ein einfaches Zeichenobjekt. Diese hat einen
-//UserCall und der ist Client vom gesuchten Format.
+// The Get reverse way: seeks the format to the specified object.
+// If the object is a SwVirtFlyDrawObj then the format of this
+// will be acquired.
+// Otherwise it is just a simple drawing object. This has a
+// UserCall and is the client of the searched format.
 
 SwFrmFmt *FindFrmFmt( SdrObject *pObj )
 {
@@ -130,7 +130,7 @@
 
 /*
  *
- * GetBoundRect liefert das BoundRect _inklusive_ Abstand des Objekts.
+ * GetBoundRect returns the BoundRect _inclusive_ distance of the object.
  *
  */
 
@@ -151,7 +151,7 @@
 return aRet;
 }
 
-//Liefert den UserCall ggf. vom Gruppenobjekt
+// Returns the UserCall if applicable from the group object
 // OD 2004-03-31 #i26791# - change return type
 SwContact* GetUserCall( const SdrObject* pObj )
 {
@@ -163,7 +163,7 @@
 return static_castSwContact*(pObj-GetUserCall());
 }
 
-// liefert sal_True falls das SrdObject ein Marquee-Object (Lauftext) ist
+// Returns sal_True if the SrdObject is a Marquee-Object (scrolling text)
 sal_Bool IsMarqueeTextObj( const SdrObject rObj )
 {
 SdrTextAniKind eTKind;
@@ -175,7 +175,7 @@
 
 /*
 |*
-|*  SwContact, Ctor und Dtor
+|*  SwContact, Ctor and Dtor
 |*
 |*/
 
@@ -643,8 +643,8 @@
 InsertObject( pObj, pObj-GetOrdNumDirect() );
 }
 
-//Controls muessen immer im Control-Layer liegen. Das gilt auch fuer
-//Gruppenobjekte, wenn diese Controls enthalten.
+//Controls have to be always in the Control-Layer. This is also true for
+//group objects, if they contain controls.
 if ( ::CheckControlLayer( pObj ) )
 {
 // set layer of object to corresponding invisible layer.
@@ -1105,7 +1105,7 @@
 return;
 }
 
-//Action aufsetzen, aber nicht wenn gerade irgendwo eine Action laeuft.
+//Put on Action, but not if presently anywhere an action runs.
 ViewShell *pSh = 0, *pOrg;
 SwRootFrm *pTmpRoot = 

[PATCH] Comment translation german - english - some corrections and ...

2013-02-13 Thread Matthias Freund (via Code Review)
Hi,

I have submitted a patch for review:

https://gerrit.libreoffice.org/2123

To pull it, you can do:

git pull ssh://gerrit.libreoffice.org:29418/core refs/changes/23/2123/1

Comment translation german - english - some corrections and improvements :-)

Change-Id: I9ad07188f2addad3369e070836b34151bf8ef9d5
---
M sw/source/core/draw/dpage.cxx
M sw/source/core/draw/drawdoc.cxx
M sw/source/filter/writer/writer.cxx
3 files changed, 10 insertions(+), 10 deletions(-)



diff --git a/sw/source/core/draw/dpage.cxx b/sw/source/core/draw/dpage.cxx
index 72cf1be..dbb61e2 100644
--- a/sw/source/core/draw/dpage.cxx
+++ b/sw/source/core/draw/dpage.cxx
@@ -111,7 +111,7 @@
 
 if ( pRect )
 {
-//The drawing demands all sides which overlap with the rest.
+//The drawing demands all pages which overlap with the rest.
 const SwRect aRect( *pRect );
 const SwFrm *pPg = pSh-GetLayout()-Lower();
 do
@@ -122,7 +122,7 @@
 }
 else
 {
-//The drawing demands all visible sides
+//The drawing demands all visible pages
 const SwFrm *pPg = pSh-Imp()-GetFirstVisPage();
 if ( pPg )
 do
diff --git a/sw/source/core/draw/drawdoc.cxx b/sw/source/core/draw/drawdoc.cxx
index 000ef8e..ee35d1e9 100644
--- a/sw/source/core/draw/drawdoc.cxx
+++ b/sw/source/core/draw/drawdoc.cxx
@@ -137,9 +137,9 @@
 /*
 |*
 |* This method creates a new page (SdPage) and thereupon returns a pointer
-|* back. The drawing engine is unsing this method while loading for the
-|* creating of pages (whose type it not even know, because they are
-|* derivations of the SdrPage).
+|* to it back. The drawing engine is using this method while loading for
+|* the creating of pages (whose type it not even know, because they are
+|* inherited from SdrPage).
 |*
 \/
 
diff --git a/sw/source/filter/writer/writer.cxx 
b/sw/source/filter/writer/writer.cxx
index 1cca958..828614c 100644
--- a/sw/source/filter/writer/writer.cxx
+++ b/sw/source/filter/writer/writer.cxx
@@ -268,7 +268,7 @@
 
 // Copy PaM, so that it can be modified
 pCurPam = new SwPaM( *rPaM.End(), *rPaM.Start() );
-// for comparison secure to the act. Pam
+// for comparison secure to the current Pam
 pOrigPam = rPaM;
 
 sal_uLong nRet = WriteStream();
@@ -353,7 +353,7 @@
 void Writer::PutNumFmtFontsInAttrPool()
 {
 // then there are a few fonts in the NumRules
-// These putt into the Pool. After this does they have a RefCount  1
+// These put into the Pool. After this does they have a RefCount  1
 // it can be removed - it is already in the Pool
 SfxItemPool rPool = pDoc-GetAttrPool();
 const SwNumRuleTbl rListTbl = pDoc-GetNumRuleTbl();
@@ -452,7 +452,7 @@
 sal_uInt16 Writer::GetBookmarks(const SwCntntNode rNd, xub_StrLen nStt,
 xub_StrLen nEnd, std::vector const ::sw::mark::IMark*  rArr)
 {
-OSL_ENSURE( rArr.empty(), there are entries available );
+OSL_ENSURE( rArr.empty(), there are still entries available );
 
 sal_uLong nNd = rNd.GetIndex();
 std::pairSwBookmarkNodeTable::const_iterator, 
SwBookmarkNodeTable::const_iterator aIterPair 
@@ -508,7 +508,7 @@
 
 // Copy PaM, so that it can be modified
 pCurPam = new SwPaM( *rPaM.End(), *rPaM.Start() );
-// for comparison secure to the act. Pam
+// for comparison secure to the current Pam
 pOrigPam = rPaM;
 
 sal_uLong nRet = WriteStorage();
@@ -529,7 +529,7 @@
 
 // Copy PaM, so that it can be modified
 pCurPam = new SwPaM( *rPaM.End(), *rPaM.Start() );
-// for comparison secure to the act. Pam
+// for comparison secure to the current Pam
 pOrigPam = rPaM;
 
 sal_uLong nRet = pMedium ? WriteMedium( *pMedium ) : WriteStorage();

-- 
To view, visit https://gerrit.libreoffice.org/2123
To unsubscribe, visit https://gerrit.libreoffice.org/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: I9ad07188f2addad3369e070836b34151bf8ef9d5
Gerrit-PatchSet: 1
Gerrit-Project: core
Gerrit-Branch: master
Gerrit-Owner: Matthias Freund matti...@yahoo.de
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[PATCH] Comment translation german - english

2013-02-13 Thread Matthias Freund (via Code Review)
Hi,

I have submitted a patch for review:

https://gerrit.libreoffice.org/2124

To pull it, you can do:

git pull ssh://gerrit.libreoffice.org:29418/core refs/changes/24/2124/1

Comment translation german - english

Change-Id: I606ed122f3761bd8a3ee84030bee5975b0b78801
---
M sw/source/core/draw/dcontact.cxx
1 file changed, 17 insertions(+), 16 deletions(-)



diff --git a/sw/source/core/draw/dcontact.cxx b/sw/source/core/draw/dcontact.cxx
index 3449521..e1a5b53 100644
--- a/sw/source/core/draw/dcontact.cxx
+++ b/sw/source/core/draw/dcontact.cxx
@@ -89,11 +89,11 @@
 }
 
 
-//Der Umgekehrte Weg: Sucht das Format zum angegebenen Objekt.
-//Wenn das Object ein SwVirtFlyDrawObj ist so wird das Format von
-//selbigem besorgt.
-//Anderfalls ist es eben ein einfaches Zeichenobjekt. Diese hat einen
-//UserCall und der ist Client vom gesuchten Format.
+// The Get reverse way: seeks the format to the specified object.
+// If the object is a SwVirtFlyDrawObj then the format of this
+// will be acquired.
+// Otherwise it is just a simple drawing object. This has a
+// UserCall and is the client of the searched format.
 
 SwFrmFmt *FindFrmFmt( SdrObject *pObj )
 {
@@ -130,7 +130,7 @@
 
 /*
  *
- * GetBoundRect liefert das BoundRect _inklusive_ Abstand des Objekts.
+ * GetBoundRect returns the BoundRect _inclusive_ distance of the object.
  *
  */
 
@@ -151,7 +151,7 @@
 return aRet;
 }
 
-//Liefert den UserCall ggf. vom Gruppenobjekt
+// Returns the UserCall if applicable from the group object
 // OD 2004-03-31 #i26791# - change return type
 SwContact* GetUserCall( const SdrObject* pObj )
 {
@@ -163,7 +163,7 @@
 return static_castSwContact*(pObj-GetUserCall());
 }
 
-// liefert sal_True falls das SrdObject ein Marquee-Object (Lauftext) ist
+// Returns sal_True if the SrdObject is a Marquee-Object (scrolling text)
 sal_Bool IsMarqueeTextObj( const SdrObject rObj )
 {
 SdrTextAniKind eTKind;
@@ -175,7 +175,7 @@
 
 /*
 |*
-|*  SwContact, Ctor und Dtor
+|*  SwContact, Ctor and Dtor
 |*
 |*/
 
@@ -643,8 +643,8 @@
 InsertObject( pObj, pObj-GetOrdNumDirect() );
 }
 
-//Controls muessen immer im Control-Layer liegen. Das gilt auch fuer
-//Gruppenobjekte, wenn diese Controls enthalten.
+//Controls have to be always in the Control-Layer. This is also true for
+//group objects, if they contain controls.
 if ( ::CheckControlLayer( pObj ) )
 {
 // set layer of object to corresponding invisible layer.
@@ -1105,7 +1105,8 @@
 return;
 }
 
-//Action aufsetzen, aber nicht wenn gerade irgendwo eine Action laeuft.
+//Put on Action, but not if presently anywhere an action runs.
+aber nicht wenn gerade irgendwo eine Action laeuft.
 ViewShell *pSh = 0, *pOrg;
 SwRootFrm *pTmpRoot = pDoc-GetCurrentLayout();//swmod 080317
 if ( pTmpRoot  pTmpRoot-IsCallbackActionEnabled() )
@@ -1125,7 +1126,7 @@
 pTmpRoot-StartAllAction();
 }
 SdrObjUserCall::Changed( rObj, eType, rOldBoundRect );
-_Changed( rObj, eType, rOldBoundRect );//Achtung, ggf. Suizid!
+_Changed( rObj, eType, rOldBoundRect );//Attention, possibly suicidal!
 
 if ( pSh )
 pTmpRoot-EndAllAction();
@@ -1203,7 +1204,7 @@
 };
 
 //
-// !!!ACHTUNG!!! The object may commit suicide!!!
+// !!!ATTENTION!!! The object may commit suicide!!!
 //
 void SwDrawContact::_Changed( const SdrObject rObj,
   SdrUserCallType eType,
@@ -1485,7 +1486,7 @@
 
 if ( pNewAnchorFmt )
 {
-// nicht auf ein Reset Anchor reagieren !
+// Do not respond to a Reset Anchor !
 if ( SFX_ITEM_SET ==
 GetFmt()-GetAttrSet().GetItemState( RES_ANCHOR, sal_False ) )
 {
@@ -1812,7 +1813,7 @@
 pPage-AppendDrawObj( maAnchoredDrawObj );
 }
 else
-//Sieht doof aus, ist aber erlaubt (vlg. 
SwFEShell::SetPageObjsNewPage)
+//Looks stupid but is allowed (compare 
SwFEShell::SetPageObjsNewPage)
 pRoot-SetAssertFlyPages();
 }
 break;

-- 
To view, visit https://gerrit.libreoffice.org/2124
To unsubscribe, visit https://gerrit.libreoffice.org/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: I606ed122f3761bd8a3ee84030bee5975b0b78801
Gerrit-PatchSet: 1
Gerrit-Project: core
Gerrit-Branch: master
Gerrit-Owner: Matthias Freund matti...@yahoo.de
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[PATCH] Comment translation german - english

2013-02-12 Thread Matthias Freund (via Code Review)
Hi,

I have submitted a patch for review:

https://gerrit.libreoffice.org/2111

To pull it, you can do:

git pull ssh://gerrit.libreoffice.org:29418/core refs/changes/11/2111/1

Comment translation german - english

Change-Id: I241f9b6c1be875577e7bc647583783bc24446413
---
M sw/source/core/docnode/ndnum.cxx
M sw/source/core/docnode/ndsect.cxx
M sw/source/core/draw/dpage.cxx
M sw/source/core/draw/drawdoc.cxx
4 files changed, 18 insertions(+), 18 deletions(-)



diff --git a/sw/source/core/docnode/ndnum.cxx b/sw/source/core/docnode/ndnum.cxx
index 86d3e44..91b861ec 100644
--- a/sw/source/core/docnode/ndnum.cxx
+++ b/sw/source/core/docnode/ndnum.cxx
@@ -21,7 +21,7 @@
 #include doc.hxx
 #include pam.hxx
 #include ndtxt.hxx
-#include fldbas.hxx   // UpdateFlds der KapitelNummerierung
+#include fldbas.hxx   // UpdateFlds of the chapter numbering
 #include docary.hxx
 
 bool CompareSwOutlineNodes::operator()( SwNode* const lhs, SwNode* const 
rhs) const
@@ -67,20 +67,20 @@
 
 pTxtNd-UpdateOutlineState();
 
-// die Gliederungs-Felder Updaten
+// update the structure fields
 GetDoc()-GetSysFldType( RES_CHAPTERFLD )-UpdateFlds();
 }
 }
 
 void SwNodes::UpdtOutlineIdx( const SwNode rNd )
 {
-if( pOutlineNds-empty() ) // keine OutlineNodes vorhanden ?
+if( pOutlineNds-empty() ) // no OutlineNodes present ?
 return;
 
 const SwNodePtr pSrch = (SwNodePtr)rNd;
 sal_uInt16 nPos;
 pOutlineNds-Seek_Entry( pSrch, nPos );
-if( nPos == pOutlineNds-size() )  // keine zum Updaten vorhanden ?
+if( nPos == pOutlineNds-size() )  // none present for updating ?
 return;
 
 if( nPos )
diff --git a/sw/source/core/docnode/ndsect.cxx 
b/sw/source/core/docnode/ndsect.cxx
index 42983c9..d798fa1 100644
--- a/sw/source/core/docnode/ndsect.cxx
+++ b/sw/source/core/docnode/ndsect.cxx
@@ -1227,7 +1227,7 @@
 // In which array am I: Nodes, UndoNodes?
 const SwNodes rNds = GetNodes();
 
-// Copy the das SectionFrmFmt
+// Copy the SectionFrmFmt
 SwSectionFmt* pSectFmt = pDoc-MakeSectionFmt( 0 );
 pSectFmt-CopyAttrs( *GetSection().GetFmt() );
 
diff --git a/sw/source/core/draw/dpage.cxx b/sw/source/core/draw/dpage.cxx
index c10134d..72cf1be 100644
--- a/sw/source/core/draw/dpage.cxx
+++ b/sw/source/core/draw/dpage.cxx
@@ -111,7 +111,7 @@
 
 if ( pRect )
 {
-//Das Drawing verlang alle Seiten, die mit dem Rect 
ueberlappen.
+//The drawing demands all sides which overlap with the rest.
 const SwRect aRect( *pRect );
 const SwFrm *pPg = pSh-GetLayout()-Lower();
 do
@@ -122,7 +122,7 @@
 }
 else
 {
-//Das Drawing verlangt alle sichbaren Seiten
+//The drawing demands all visible sides
 const SwFrm *pPg = pSh-Imp()-GetFirstVisPage();
 if ( pPg )
 do
@@ -174,11 +174,11 @@
 
 if( rURL.IsServerMap() )
 {
-// dann die rel. Pixel Position anhaengen !!
+// then append the relative pixel position!!
 Point aPt( aPos );
 aPt -= pFly-Frm().Pos();
-// ohne MapMode-Offset !
-// ohne MapMode-Offset, ohne Offset, o ... !
+// without MapMode-Offset !
+// without MapMode-Offset, without Offset, w ... !
 aPt = pWindow-LogicToPixel(
 aPt, MapMode( MAP_TWIP ) );
 ((( sTxt += '?' ) += String::CreateFromInt32( aPt.X() ))
@@ -209,7 +209,7 @@
 }
 else
 {
-// dann zeige die Hilfe mal an:
+// then display the help:
 Rectangle aRect( rEvt.GetMousePosPixel(), Size(1,1) );
 Help::ShowQuickHelp( pWindow, aRect, sTxt );
 }
diff --git a/sw/source/core/draw/drawdoc.cxx b/sw/source/core/draw/drawdoc.cxx
index ef814bc..000ef8e 100644
--- a/sw/source/core/draw/drawdoc.cxx
+++ b/sw/source/core/draw/drawdoc.cxx
@@ -42,7 +42,7 @@
 
 /*
 |*
-|* Konstruktor
+|* Constructor
 |*
 \/
 
@@ -122,7 +122,7 @@
 
 /*
 |*
-|* Destruktor
+|* Destructor
 |*
 \/
 
@@ -136,10 +136,10 @@
 
 /*
 |*
-|* Diese Methode erzeugt eine neue Seite (SdPage) und gibt einen Zeiger
-|* darauf zurueck. Die Drawing Engine benutzt diese Methode beim Laden
-|* zur Erzeugung von Seiten (deren Typ sie ja nicht 

[PATCH] Comment translation german - english

2013-02-12 Thread Matthias Freund (via Code Review)
Hi,

I have submitted a patch for review:

https://gerrit.libreoffice.org/2113

To pull it, you can do:

git pull ssh://gerrit.libreoffice.org:29418/core refs/changes/13/2113/1

Comment translation german - english

Change-Id: I00d584f4d0ba9b138a1a860456a3fd06daa914ed
---
M sw/source/filter/writer/writer.cxx
1 file changed, 34 insertions(+), 34 deletions(-)



diff --git a/sw/source/filter/writer/writer.cxx 
b/sw/source/filter/writer/writer.cxx
index 21dd1bc..1cca958 100644
--- a/sw/source/filter/writer/writer.cxx
+++ b/sw/source/filter/writer/writer.cxx
@@ -37,7 +37,7 @@
 using namespace ::com::sun::star;
 
 
-// Stringbuffer fuer die umgewandelten Zahlen
+// Stringbuffer for the converted numbers
 static sal_Char aNToABuf[] = 0;
 #define NTOABUFLEN (sizeof(aNToABuf))
 
@@ -91,16 +91,16 @@
 }
 
 /*
- * Dieses Modul ist die Zentrale-Sammelstelle fuer alle Write-Filter
- * und ist eine DLL !
+ * This module is the central collection point for all writer-filters
+ * and is a DLL !
  *
- * Damit der Writer mit den unterschiedlichen Writern arbeiten kann,
- * muessen fuer diese die Ausgabe-Funktionen der Inhalts tragenden
- * Objecte auf die verschiedenen Ausgabe-Funktionen gemappt werden.
+ * So that the Writer can work with different writers, the output-functions
+ * of the content carrying objects have to be mapped to the various
+ * output-functions.
  *
- * Dazu kann fuer jedes Object ueber den Which-Wert in einen Tabelle ge-
- * griffen werden, um seine Ausgabe-Funktion zu erfragen.
- * Diese Funktionen stehen in den entsprechenden Writer-DLL's.
+ * For that, to inquire its output function, every object can be gripped
+ * via the which-value in a table.
+ * These functions are available in the corresponding Writer-DLL's.
  */
 
 Writer::Writer()
@@ -151,8 +151,8 @@
 {
 if( (*ppPam)-GetNext() == pOrigPam )
 {
-*ppPam = pOrigPam;  // wieder auf den Anfangs-Pam setzen
-return sal_False;   // Ende vom Ring
+*ppPam = pOrigPam;  // set back to the beginning pam
+return sal_False;   // end of the ring
 }
 
 // ansonsten kopiere den die Werte aus dem naechsten Pam
@@ -164,7 +164,7 @@
 return sal_True;
 }
 
-// suche die naechste Bookmark-Position aus der Bookmark-Tabelle
+// search the next Bookmark-Position from the Bookmark-Table
 
 sal_Int32 Writer::FindPos_Bkmk(const SwPosition rPos) const
 {
@@ -189,7 +189,7 @@
 SwCntntNode* pCNode = aStt.GetNode().GetCntntNode();
 if( !pCNode  0 == ( pCNode = pNds-GoNext( aStt )) )
 {
-OSL_FAIL( An StartPos kein ContentNode mehr );
+OSL_FAIL( No more ContentNode at StartPos );
 }
 
 SwPaM* pNew = new SwPaM( aStt );
@@ -198,7 +198,7 @@
 if( 0 == (pCNode = aStt.GetNode().GetCntntNode()) 
 0 == (pCNode = pNds-GoPrevious( aStt )) )
 {
-OSL_FAIL( An StartPos kein ContentNode mehr );
+OSL_FAIL( No more ContentNode at StartPos );
 }
 pCNode-MakeEndIndex( pNew-GetPoint()-nContent );
 pNew-GetPoint()-nNode = aStt;
@@ -207,7 +207,7 @@
 
 /
 
-// Stream-spezifisches
+// Stream-specific
 SvStream Writer::Strm()
 {
 OSL_ENSURE( m_pImpl-m_pStream, Oh-oh. Writer with no Stream! );
@@ -219,7 +219,7 @@
 
 SvStream Writer::OutLong( SvStream rStrm, long nVal )
 {
-// Pointer an das Bufferende setzen
+// Set the Pointer at the end of the buffer
 sal_Char* pStr = aNToABuf + (NTOABUFLEN-1);
 
 int bNeg = nVal  0;
@@ -231,7 +231,7 @@
 nVal /= 10;
 } while( nVal );
 
-// Ist Zahl negativ, dann noch -
+// is the number negative, then in addition -
 if( bNeg )
 *(--pStr) = '-';
 
@@ -240,7 +240,7 @@
 
 SvStream Writer::OutULong( SvStream rStrm, sal_uLong nVal )
 {
-// Pointer an das Bufferende setzen
+// Set the Pointer at the end of the buffer
 sal_Char* pStr = aNToABuf + (NTOABUFLEN-1);
 
 do {
@@ -266,9 +266,9 @@
 pOrigFileName = pFName;
 m_pImpl-m_pStream = rStrm;
 
-// PaM kopieren, damit er veraendert werden kann
+// Copy PaM, so that it can be modified
 pCurPam = new SwPaM( *rPaM.End(), *rPaM.Start() );
-// zum Vergleich auf den akt. Pam sichern
+// for comparison secure to the act. Pam
 pOrigPam = rPaM;
 
 sal_uLong nRet = WriteStream();
@@ -287,13 +287,13 @@
 
 sal_uLong Writer::Write( SwPaM /*rPam*/, SvStorage, const String* )
 {
-OSL_ENSURE( !this, Schreiben in Storages auf einem Stream? );
+OSL_ENSURE( !this, Write in Storages on a stream? );
 return ERR_SWG_WRITE_ERROR;
 }
 
 sal_uLong Writer::Write( SwPaM, const uno::Reference  embed::XStorage , 
const String*, SfxMedium* )
 {
-OSL_ENSURE( !this, Schreiben in Storages auf einem Stream? );
+OSL_ENSURE( !this, Write in Storages on a stream? );
 return ERR_SWG_WRITE_ERROR;
 }
 
@@ -314,7 +314,7 @@
 
 if (m_pImpl-pFileNameMap)
 {

[PATCH] Comment translation german - english.

2013-02-11 Thread Matthias Freund (via Code Review)
Hi,

I have submitted a patch for review:

https://gerrit.libreoffice.org/2070

To pull it, you can do:

git pull ssh://gerrit.libreoffice.org:29418/core refs/changes/70/2070/1

Comment translation german - english.

sw/source/ui/wrtsh/delete.cxx

Change-Id: I92487e7474c4e27cee939812edf410e9a26731e7
---
M sw/source/ui/wrtsh/delete.cxx
1 file changed, 15 insertions(+), 15 deletions(-)



diff --git a/sw/source/ui/wrtsh/delete.cxx b/sw/source/ui/wrtsh/delete.cxx
index 6f6d3aa..d858742 100644
--- a/sw/source/ui/wrtsh/delete.cxx
+++ b/sw/source/ui/wrtsh/delete.cxx
@@ -83,7 +83,7 @@
 }
 
 /*
- Beschreibung:  Zeile loeschen
+ Description: Erase the line
 */
 
 
@@ -92,7 +92,7 @@
 {
 SwActContext aActContext(this);
 ResetCursorStack();
-// alten Cursor merken
+// remember the old cursor
 Push();
 ClearMark();
 SwCrsrShell::LeftMargin();
@@ -130,7 +130,7 @@
 
 long SwWrtShell::DelLeft()
 {
-// wenns denn ein Fly ist, wech damit
+// If it's a Fly, throw it away
 int nSelType = GetSelectionType();
 const int nCmp = nsSelectionType::SEL_FRM | nsSelectionType::SEL_GRF | 
nsSelectionType::SEL_OLE | nsSelectionType::SEL_DRW;
 if( nCmp  nSelType )
@@ -156,13 +156,13 @@
 return 1L;
 }
 
-// wenn eine Selektion existiert, diese loeschen.
+// If a selection exists, erase this
 if ( IsSelection() )
 {
 if( !IsBlockMode() || HasSelection() )
 {
-//OS: wieder einmal Basic: SwActContext muss vor
-//EnterStdMode verlassen werden!
+//OS: Once again Basic: SwActContext must be leaved
+//before EnterStdMode!
 {
 SwActContext aActContext(this);
 ResetCursorStack();
@@ -183,7 +183,7 @@
 EnterStdMode();
 }
 
-// JP 29.06.95: nie eine davor stehende Tabelle loeschen.
+// JP 29.06.95: never erase a table wich standing in front of.
 bool bSwap = false;
 const SwTableNode * pWasInTblNd = SwCrsrShell::IsCrsrInTbl();
 
@@ -234,8 +234,8 @@
 
 long SwWrtShell::DelRight()
 {
-// werden verodert, wenn Tabellenselektion vorliegt;
-// wird hier auf nsSelectionType::SEL_TBL umgesetzt.
+// Will be or'ed, if a tableselection exists;
+// will here be implemented on nsSelectionType::SEL_TBL
 long nRet = 0;
 int nSelection = GetSelectionType();
 if(nSelection  nsSelectionType::SEL_TBL_CELLS)
@@ -251,13 +251,13 @@
 case nsSelectionType::SEL_TXT:
 case nsSelectionType::SEL_TBL:
 case nsSelectionType::SEL_NUM:
-//  wenn eine Selektion existiert, diese loeschen.
+//  If a selection exists, erase it.
 if( IsSelection() )
 {
 if( !IsBlockMode() || HasSelection() )
 {
-//OS: wieder einmal Basic: SwActContext muss vor
-//EnterStdMode verlassen werden!
+//OS: And once again Basic: SwActContext must be
+//leaved before EnterStdMode !
 {
 SwActContext aActContext(this);
 ResetCursorStack();
@@ -445,9 +445,9 @@
 return nRet;
 }
 /*
- * alle Loeschoperationen sollten mit Find statt mit
- * Nxt-/PrvDelim arbeiten, da letzteren mit Wrap Around arbeiten
- * -- das ist wohl nicht gewuenscht.
+ * All erase operations should work with Find instead with
+ * Nxt-/PrvDelim, because the latter works with Wrap Around
+ * -- that's probably not wished.
  */
 
 

-- 
To view, visit https://gerrit.libreoffice.org/2070
To unsubscribe, visit https://gerrit.libreoffice.org/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: I92487e7474c4e27cee939812edf410e9a26731e7
Gerrit-PatchSet: 1
Gerrit-Project: core
Gerrit-Branch: master
Gerrit-Owner: Matthias Freund matti...@yahoo.de
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[PATCH] Comment translation german - english

2013-02-11 Thread Matthias Freund (via Code Review)
Hi,

I have submitted a patch for review:

https://gerrit.libreoffice.org/2071

To pull it, you can do:

git pull ssh://gerrit.libreoffice.org:29418/core refs/changes/71/2071/1

Comment translation german - english

Translation.

Change-Id: I07d8f85437ce6ff59ac40970de29cc2fccde3d5a
---
M sw/sdi/docsh.sdi
1 file changed, 1 insertion(+), 1 deletion(-)



diff --git a/sw/sdi/docsh.sdi b/sw/sdi/docsh.sdi
index 2c8a9e9..83253dc 100644
--- a/sw/sdi/docsh.sdi
+++ b/sw/sdi/docsh.sdi
@@ -21,7 +21,7 @@
 uuid = 0D960120-111C-101D-9757-6E74207A7520
 ]
 {
-// Slots, die nicht in der WebDocShell gebraucht werden
+// Slots, wich are not needed in the WebDocShell
 
 FN_OUTLINE_TO_IMPRESS
 [

-- 
To view, visit https://gerrit.libreoffice.org/2071
To unsubscribe, visit https://gerrit.libreoffice.org/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: I07d8f85437ce6ff59ac40970de29cc2fccde3d5a
Gerrit-PatchSet: 1
Gerrit-Project: core
Gerrit-Branch: master
Gerrit-Owner: Matthias Freund matti...@yahoo.de
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[PATCH] Comment translation german - english

2013-02-11 Thread Matthias Freund (via Code Review)
Hi,

I have submitted a patch for review:

https://gerrit.libreoffice.org/2072

To pull it, you can do:

git pull ssh://gerrit.libreoffice.org:29418/core refs/changes/72/2072/1

Comment translation german - english

This times i have more files with few translations.

Change-Id: I5a6cb89a36b8fab3db8cfb4029316e51834445b6
---
M sw/sdi/tabsh.sdi
M sw/sdi/textsh.sdi
M sw/sdi/viewsh.sdi
M sw/sdi/wdocsh.sdi
4 files changed, 6 insertions(+), 6 deletions(-)



diff --git a/sw/sdi/tabsh.sdi b/sw/sdi/tabsh.sdi
index cb2f2b1..3f78944 100644
--- a/sw/sdi/tabsh.sdi
+++ b/sw/sdi/tabsh.sdi
@@ -21,8 +21,8 @@
 uuid = 49CE7CA0-111A-101D-9757-6E74207A7520
 ]
 {
-// hier sollen die Slots eingefuegt werden, die vom StarWriter/WEB
-// nicht unterstuetzt werden
+// Here should the slots be integrated, which are not supported
+// in StarWriter/WEB
 
 import TextSelection;
 
diff --git a/sw/sdi/textsh.sdi b/sw/sdi/textsh.sdi
index e6cd93c..b817536 100644
--- a/sw/sdi/textsh.sdi
+++ b/sw/sdi/textsh.sdi
@@ -28,8 +28,8 @@
 DisableFlags=SW_DISABLE_ON_PROTECTED_CURSOR;
 Cachable ;
 ]
- // hier sollen die Slots eingefuegt werden, die vom StarWriter/WEB
- // nicht unterstuetzt werden
+ // Here should the slots be integrated, which are not supported
+ // in StarWriter/WEB
 
 import TextSelection;
 
diff --git a/sw/sdi/viewsh.sdi b/sw/sdi/viewsh.sdi
index 479a188..e6b4bc3 100644
--- a/sw/sdi/viewsh.sdi
+++ b/sw/sdi/viewsh.sdi
@@ -43,7 +43,7 @@
 uuid = 09782660-111A-101D-9757-6E74207A7520
 ]
 {
- // Slots, die nicht in der WebDocShell gebraucht werden
+ // Slots, wich are not needed in the WebDocShell
 FN_INSERT_OBJ_CTRL
 [
 ExecMethod = Execute ;
diff --git a/sw/sdi/wdocsh.sdi b/sw/sdi/wdocsh.sdi
index 68bfe71..f3d62b9 100644
--- a/sw/sdi/wdocsh.sdi
+++ b/sw/sdi/wdocsh.sdi
@@ -21,7 +21,7 @@
 uuid = B47F0DE4-1E1F-11d1-89CA-008029E4B0B1
 ]
 {
-// hier nur Slots, die der vollstaendige Writer nicht braucht
+// here only Slots, which the full Writer doesn't need
 SID_SOURCEVIEW
 [
 ExecMethod = Execute ;

-- 
To view, visit https://gerrit.libreoffice.org/2072
To unsubscribe, visit https://gerrit.libreoffice.org/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: I5a6cb89a36b8fab3db8cfb4029316e51834445b6
Gerrit-PatchSet: 1
Gerrit-Project: core
Gerrit-Branch: master
Gerrit-Owner: Matthias Freund matti...@yahoo.de
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[PATCH] Comment translation german - english

2013-02-11 Thread Matthias Freund (via Code Review)
Hi,

I have submitted a patch for review:

https://gerrit.libreoffice.org/2073

To pull it, you can do:

git pull ssh://gerrit.libreoffice.org:29418/core refs/changes/73/2073/1

Comment translation german - english

And again a litte change...

Change-Id: Ia2fe42dc34983755a8ed23d188f41f73be71e5c8
---
M sw/sdi/wtextsh.sdi
1 file changed, 2 insertions(+), 2 deletions(-)



diff --git a/sw/sdi/wtextsh.sdi b/sw/sdi/wtextsh.sdi
index 818f3fd..94af14e 100644
--- a/sw/sdi/wtextsh.sdi
+++ b/sw/sdi/wtextsh.sdi
@@ -28,8 +28,8 @@
 DisableFlags=SW_DISABLE_ON_PROTECTED_CURSOR;
 Cachable ;
 ]
-// hier sollen die Slots eingefuegt werden, die n u r vom StarWriter/WEB
-// unterstuetzt werden
+// Here should the slots are be inserted, but O N L Y those that are 
supported
+// by StarWriter/WEB
 import TextSelection;
 }
 

-- 
To view, visit https://gerrit.libreoffice.org/2073
To unsubscribe, visit https://gerrit.libreoffice.org/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: Ia2fe42dc34983755a8ed23d188f41f73be71e5c8
Gerrit-PatchSet: 1
Gerrit-Project: core
Gerrit-Branch: master
Gerrit-Owner: Matthias Freund matti...@yahoo.de
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[PATCH] Comment translation german - english

2013-02-11 Thread Matthias Freund (via Code Review)
Hi,

I have submitted a patch for review:

https://gerrit.libreoffice.org/2074

To pull it, you can do:

git pull ssh://gerrit.libreoffice.org:29418/core refs/changes/74/2074/1

Comment translation german - english

Hope it helps a lot.

Change-Id: If10593f81d4b2a00b8305e955ca7e6a15ed47aff
---
M sw/source/ui/table/tablepg.hxx
1 file changed, 4 insertions(+), 4 deletions(-)



diff --git a/sw/source/ui/table/tablepg.hxx b/sw/source/ui/table/tablepg.hxx
index 091754d..618f93a 100644
--- a/sw/source/ui/table/tablepg.hxx
+++ b/sw/source/ui/table/tablepg.hxx
@@ -90,9 +90,9 @@
 };
 
 /*---
- TabPage Format/Tabelle/Spalten
+ TabPage Format/Table/Columns
 - */
-#define MET_FIELDS 6 //Anzahl der verwendeten MetricFields
+#define MET_FIELDS 6 //Number of the used MetricFields
 
 class SwTableColumnPage : public SfxTabPage
 {
@@ -110,8 +110,8 @@
 SwTwips nMinWidth;
 sal_uInt16  nNoOfCols;
 sal_uInt16  nNoOfVisibleCols;
-//Breite merken, wenn auf autom. Ausrichtung gestellt wird
-sal_uInt16  aValueTbl[MET_FIELDS];//primaere Zuordnung der 
MetricFields
+//Remember the with, when switching to autoalign
+sal_uInt16  aValueTbl[MET_FIELDS];//primary assignment of the 
MetricFields
 sal_BoolbModified:1;
 sal_BoolbModifyTbl:1;
 sal_BoolbPercentMode:1;

-- 
To view, visit https://gerrit.libreoffice.org/2074
To unsubscribe, visit https://gerrit.libreoffice.org/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: If10593f81d4b2a00b8305e955ca7e6a15ed47aff
Gerrit-PatchSet: 1
Gerrit-Project: core
Gerrit-Branch: master
Gerrit-Owner: Matthias Freund matti...@yahoo.de
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[PATCH] Comment translation german - english - correction

2013-02-11 Thread Matthias Freund (via Code Review)
Hi,

I have submitted a patch for review:

https://gerrit.libreoffice.org/2083

To pull it, you can do:

git pull ssh://gerrit.libreoffice.org:29418/core refs/changes/83/2083/1

Comment translation german - english - correction

Change-Id: I4aec4bcf67cb2e07a4cf6d1db705438d0b94b5b7
Ooops: the width !
---
M sw/source/ui/table/tablepg.hxx
1 file changed, 1 insertion(+), 1 deletion(-)



diff --git a/sw/source/ui/table/tablepg.hxx b/sw/source/ui/table/tablepg.hxx
index 618f93a..e65a574 100644
--- a/sw/source/ui/table/tablepg.hxx
+++ b/sw/source/ui/table/tablepg.hxx
@@ -110,7 +110,7 @@
 SwTwips nMinWidth;
 sal_uInt16  nNoOfCols;
 sal_uInt16  nNoOfVisibleCols;
-//Remember the with, when switching to autoalign
+//Remember the width, when switching to autoalign
 sal_uInt16  aValueTbl[MET_FIELDS];//primary assignment of the 
MetricFields
 sal_BoolbModified:1;
 sal_BoolbModifyTbl:1;

-- 
To view, visit https://gerrit.libreoffice.org/2083
To unsubscribe, visit https://gerrit.libreoffice.org/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: I4aec4bcf67cb2e07a4cf6d1db705438d0b94b5b7
Gerrit-PatchSet: 1
Gerrit-Project: core
Gerrit-Branch: master
Gerrit-Owner: Matthias Freund matti...@yahoo.de
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[PATCH] Comment translation german - english

2013-02-11 Thread Matthias Freund (via Code Review)
Hi,

I have submitted a patch for review:

https://gerrit.libreoffice.org/2084

To pull it, you can do:

git pull ssh://gerrit.libreoffice.org:29418/core refs/changes/84/2084/1

Comment translation german - english

Change-Id: I3af5ce71bb7758ae422e664ce2e0a44b8768134f
---
M sw/inc/poolfmt.hrc
1 file changed, 27 insertions(+), 27 deletions(-)



diff --git a/sw/inc/poolfmt.hrc b/sw/inc/poolfmt.hrc
index 38b522c..4d23941 100644
--- a/sw/inc/poolfmt.hrc
+++ b/sw/inc/poolfmt.hrc
@@ -21,10 +21,10 @@
 #include rcid.hrc
 
 // ---
-// die Formate
+// The Formats
 // ---
 
-// Zeichenvorlagen:
+// Drawing Templates:
 #define STR_POOLCHR_FOOTNOTE(RC_POOLCHRFMT_BEGIN+  0)
 #define STR_POOLCHR_PAGENO  (RC_POOLCHRFMT_BEGIN+  1)
 #define STR_POOLCHR_LABEL   (RC_POOLCHRFMT_BEGIN+  2)
@@ -53,7 +53,7 @@
 #define STR_POOLCHR_HTML_DEFINSTANCE(RC_POOLCHRFMT_HTML_BEGIN+  7)
 #define STR_POOLCHR_HTML_TELETYPE   (RC_POOLCHRFMT_HTML_BEGIN+  8)
 
-// Rahmen-Vorlagen:
+// Frame Templates:
 #define STR_POOLFRM_FRAME   (RC_POOLFRMFMT_BEGIN+  0)
 #define STR_POOLFRM_GRAPHIC (RC_POOLFRMFMT_BEGIN+  1)
 #define STR_POOLFRM_OLE (RC_POOLFRMFMT_BEGIN+  2)
@@ -63,9 +63,9 @@
 #define STR_POOLFRM_LABEL   (RC_POOLFRMFMT_BEGIN+  6)
 
 // ---
-// die Vorlagen
+// The Templates
 // ---
-// Gruppe Text
+// Category Text
 #define STR_POOLCOLL_STANDARD   (RC_POOLCOLL_TEXT_BEGIN+  0)
 #define STR_POOLCOLL_TEXT   (RC_POOLCOLL_TEXT_BEGIN+  1)
 #define STR_POOLCOLL_TEXT_IDENT (RC_POOLCOLL_TEXT_BEGIN+  2)
@@ -76,7 +76,7 @@
 #define STR_POOLCOLL_CONFRONTATION  (RC_POOLCOLL_TEXT_BEGIN+  7)
 #define STR_POOLCOLL_MARGINAL   (RC_POOLCOLL_TEXT_BEGIN+  8)
 
-// Untergruppierung Ueberschriften
+// Subcategory Headlines
 #define STR_POOLCOLL_HEADLINE_BASE  (RC_POOLCOLL_TEXT_BEGIN+  9)
 #define STR_POOLCOLL_HEADLINE1  (RC_POOLCOLL_TEXT_BEGIN+ 10)
 #define STR_POOLCOLL_HEADLINE2  (RC_POOLCOLL_TEXT_BEGIN+ 11)
@@ -89,9 +89,9 @@
 #define STR_POOLCOLL_HEADLINE9  (RC_POOLCOLL_TEXT_BEGIN+ 18)
 #define STR_POOLCOLL_HEADLINE10 (RC_POOLCOLL_TEXT_BEGIN+ 19)
 
-// Gruppe Listen
+// Category Lists
 #define STR_POOLCOLL_NUMBUL_BASE(RC_POOLCOLL_LISTS_BEGIN+  0)
-// Untergruppe Nummerierung
+// Subcategory Numbering
 #define STR_POOLCOLL_NUM_LEVEL1S(RC_POOLCOLL_LISTS_BEGIN+  1)
 #define STR_POOLCOLL_NUM_LEVEL1 (RC_POOLCOLL_LISTS_BEGIN+  2)
 #define STR_POOLCOLL_NUM_LEVEL1E(RC_POOLCOLL_LISTS_BEGIN+  3)
@@ -113,7 +113,7 @@
 #define STR_POOLCOLL_NUM_LEVEL5E(RC_POOLCOLL_LISTS_BEGIN+ 19)
 #define STR_POOLCOLL_NUM_NONUM5 (RC_POOLCOLL_LISTS_BEGIN+ 20)
 
-// Untergruppe Aufzaehlung
+// Subcategory Enumeration
 #define STR_POOLCOLL_BUL_LEVEL1S(RC_POOLCOLL_LISTS_BEGIN+ 21)
 #define STR_POOLCOLL_BUL_LEVEL1 (RC_POOLCOLL_LISTS_BEGIN+ 22)
 #define STR_POOLCOLL_BUL_LEVEL1E(RC_POOLCOLL_LISTS_BEGIN+ 23)
@@ -135,28 +135,28 @@
 #define STR_POOLCOLL_BUL_LEVEL5E(RC_POOLCOLL_LISTS_BEGIN+ 39)
 #define STR_POOLCOLL_BUL_NONUM5 (RC_POOLCOLL_LISTS_BEGIN+ 40)
 
-// Sonderbereiche
-// Untergruppe Header
+// Special Areas
+// Subcategory Header
 #define STR_POOLCOLL_HEADER (RC_POOLCOLL_EXTRA_BEGIN+  0)
 #define STR_POOLCOLL_HEADERL(RC_POOLCOLL_EXTRA_BEGIN+  1)
 #define STR_POOLCOLL_HEADERR(RC_POOLCOLL_EXTRA_BEGIN+  2)
 
-// Untergruppe Footer
+// Subcategroy Footer
 #define STR_POOLCOLL_FOOTER (RC_POOLCOLL_EXTRA_BEGIN+  3)
 #define STR_POOLCOLL_FOOTERL(RC_POOLCOLL_EXTRA_BEGIN+  4)
 #define STR_POOLCOLL_FOOTERR(RC_POOLCOLL_EXTRA_BEGIN+  5)
 
-// Untergruppe Tabelle
+// Subcategroy Table
 #define STR_POOLCOLL_TABLE  (RC_POOLCOLL_EXTRA_BEGIN+  6)
 #define STR_POOLCOLL_TABLE_HDLN (RC_POOLCOLL_EXTRA_BEGIN+  7)
 
-// Untergruppe Labels
+// Subcategroy Labels
 #define STR_POOLCOLL_LABEL  (RC_POOLCOLL_EXTRA_BEGIN+  8)
 #define STR_POOLCOLL_LABEL_ABB  (RC_POOLCOLL_EXTRA_BEGIN+  9)
 #define STR_POOLCOLL_LABEL_TABLE(RC_POOLCOLL_EXTRA_BEGIN+ 10)
 #define STR_POOLCOLL_LABEL_FRAME(RC_POOLCOLL_EXTRA_BEGIN+ 11)
 
-// sonstiges
+// Miscellaneous
 #define STR_POOLCOLL_FRAME  (RC_POOLCOLL_EXTRA_BEGIN+ 12)
 #define STR_POOLCOLL_FOOTNOTE   (RC_POOLCOLL_EXTRA_BEGIN+ 13)
 #define STR_POOLCOLL_JAKETADRESS(RC_POOLCOLL_EXTRA_BEGIN+ 14)
@@ -165,16 +165,16 @@
 
 #define STR_POOLCOLL_LABEL_DRAWING  (RC_POOLCOLL_EXTRA_BEGIN+ 17)
 
-// Gruppe Verzeichnisse
+// Category Directories
 #define STR_POOLCOLL_REGISTER_BASE  (RC_POOLCOLL_REGISTER_BEGIN+  0)
-// Untergruppe Index-Verzeichnisse
+// Subcategory Index-Directories
 #define STR_POOLCOLL_TOX_IDXH   (RC_POOLCOLL_REGISTER_BEGIN+  1)
 

[PATCH] Comment translation german - english

2013-02-11 Thread Matthias Freund (via Code Review)
Hi,

I have submitted a patch for review:

https://gerrit.libreoffice.org/2085

To pull it, you can do:

git pull ssh://gerrit.libreoffice.org:29418/core refs/changes/85/2085/1

Comment translation german - english

Change-Id: I752eaaeaa9835efb010da376824b10f25085bede
---
M sw/inc/rcid.hrc
1 file changed, 24 insertions(+), 24 deletions(-)



diff --git a/sw/inc/rcid.hrc b/sw/inc/rcid.hrc
index 9dd0961..96fefd5 100644
--- a/sw/inc/rcid.hrc
+++ b/sw/inc/rcid.hrc
@@ -22,7 +22,7 @@
 
 #define IMAGE_MASK_COLOR Color { Red = 0xFF00; Green = 0x; Blue = 0xFF00; }
 // 
-// Bereiche fuer die UI-Verzeichnisse
+// Areas for the UI-Directories
 // 
 
 #define RC_BASE RID_SW_START// From solar.hrc
@@ -71,14 +71,14 @@
 #define RC_IDXTXT   (RC_BASE + 4350)
 
 /*
-Beschreibung:   Bereiche ausspannen
+Description: areas unharness
  */
 
-// App-Verzeichnis
+// App-Directory
 #define RC_APP_BEGINRC_APP
 #define RC_APP_END  (RC_APP_BEGIN + 199)
 
-// Dialog-Verzeichnis
+// Dialog-Directory
 #define RC_DIALOG_BEGIN RC_DIALOG
 #define RC_DIALOG_END   (RC_DIALOG_BEGIN + 99)
 
@@ -106,15 +106,15 @@
 #define RC_VIEW_BEGIN   RC_VIEW
 #define RC_VIEW_END (RC_VIEW_BEGIN + 99)
 
-// Zeichen Absatz Tab-Dialog
+// Character Paragraph Tab-Dialog
 #define RC_CHRDLG_BEGIN RC_CHRDLG
 #define RC_CHRDLG_END   (RC_CHRDLG_BEGIN + 19)
 
-// Unsere Shell
+// Our Shell
 #define RC_WRTSH_BEGIN  RC_WRTSH
 #define RC_WRTSH_END(RC_WRTSH_BEGIN + 49)
 
-// Verzeichnisse
+// Directories
 #define RC_INDEX_BEGIN  RC_INDEX
 //  RC_INDEX_END(RC_INDEX + 99)
 
@@ -122,15 +122,15 @@
 #define RC_RIBBAR_BEGIN RC_RIBBAR
 #define RC_RIBBAR_END   (RC_RIBBAR_BEGIN + 79)
 
-// globale Resourcen
+// Global Resources
 #define RC_GLOBALS_BEGINRC_GLOBALS
 #define RC_GLOBALS_END  (RC_GLOBALS_BEGIN + 120)
 
-// Format-Vorlagen
+// Format-Templates
 #define RC_FMTUI_BEGIN  RC_FMTUI
 #define RC_FMTUI_END(RC_FMTUI_BEGIN + 69)
 
-// Grafik Dialoge
+// Graphic Dialogues
 #define RC_GRFDLG_BEGIN RC_GRFDLG
 //  RC_GRFDLG_END   (RC_GRFDLG_BEGIN + 99)
 
@@ -138,11 +138,11 @@
 #define RC_FSTDLG_BEGIN RC_FSTDLG
 //  RC_FSTDLG_END   (RC_FSTDLG_BEGIN + 99)
 
-// Rahmen Dialoge
+// Frame Dialogue
 #define RC_FRMDLG_BEGIN RC_FRMDLG
 #define RC_FRMDLG_END   (RC_FRMDLG_BEGIN + 99)
 
-// Feld Dialoge
+// Field Dialogue
 #define RC_FLDDLG_BEGIN RC_FLDDLG
 //  RC_FLDDLG_END   (RC_FLDDLG_BEGIN + 149)
 
@@ -150,20 +150,20 @@
 #define RC_UTLUI_BEGIN  RC_UTLUI
 #define RC_UTLUI_END(RC_UTLUI + 99)
 
-// Utilities UI-Attribute
+// Utilities UI-Attributes
 #define RC_ATTR_BEGIN   RC_ATTR
 #define RC_ATTR_END (RC_ATTR + 99)
 
-// Tabellen
+// Tables
 #define RC_TABLE_BEGIN  RC_TABLE
 #define RC_TABLE_END(RC_TABLE + 99)
 
-// Konfiguration
+// Configuration
 #define RC_CONFIG_BEGIN RC_CONFIG
 #define RC_CONFIG_END   (RC_CONFIG + 99)
 
 
-// Verschiedenes
+// Miscellaneous
 #define RC_MISC_BEGIN   RC_MISC
 #define RC_MISC_END (RC_MISC + 99)
 
@@ -171,18 +171,18 @@
 #define RC_DBUI_BEGIN   RC_DBUI
 //  RC_DBUI_END (RC_DBUI + 99)
 
-// Der Rest der Imp-Klassen
+// The rest of the Imp-Classes
 #define RC_DOCHDL_BEGIN RC_DOCHDL
 #define RC_DOCHDL_END   (RC_DOCHDL + 99)
 
-// Zeichenvorlagen
+// Drawing Templates
 #define RC_POOLCHRFMT_BEGIN RC_POOLCHRFMT
 //  RC_POOLCHRFMT_END   (RC_POOLCHRFMT + 29)
 #define RC_POOLCHRFMT_HTML_BEGINRC_POOLHTMLCHRFMT
 //  RC_POOLCHRFMT_HTML_END  (RC_POOLHTMLCHRFMT+ 30)
 
 
-// Rahmenvorlagen
+// Frame-Templates
 #define RC_POOLFRMFMT_BEGIN RC_POOLFRMFMT
 //  RC_POOLFRMFMT_END   (RC_POOLFRMFMT + 20)
 
@@ -202,27 +202,27 @@
 #define RC_POOLCOLL_HTML_END(RC_POOLTXTCOLL + 169)
 
 
-// Poolvorlagen Seite
+// Pooltemplates Page
 #define RC_POOLPAGEDESC_BEGIN   RC_POOLPAGEDESC
 //  RC_POOLPAGEDESC_END (RC_POOLPAGEDESC + 10)
 
-// Poolvorlagen Numerierung
+// Pooltemplates Numbering
 #define RC_POOLNUMRULE_BEGINRC_POOLNUMRULE
 //  RC_POOLNUMRULE_END  (RC_POOLNUMRULE + 10)
 
 // free: STR_POOLPARSTYLE to (STR_POOLPARSTYLE + 9)
 
-// Envelp-Verzeichnis
+// Envelp-Directory
 #define RC_ENVELP_BEGIN (RC_ENVELP )
 //  

[PATCH] Comment translation german - english

2013-02-11 Thread Matthias Freund (via Code Review)
Hi,

I have submitted a patch for review:

https://gerrit.libreoffice.org/2087

To pull it, you can do:

git pull ssh://gerrit.libreoffice.org:29418/core refs/changes/87/2087/1

Comment translation german - english

Change-Id: Id40b6528515a9ebcf3deb0f84597955723118a15
---
M sw/inc/swtable.hxx
1 file changed, 1 insertion(+), 1 deletion(-)



diff --git a/sw/inc/swtable.hxx b/sw/inc/swtable.hxx
index 81f2696..fe018f6 100644
--- a/sw/inc/swtable.hxx
+++ b/sw/inc/swtable.hxx
@@ -141,7 +141,7 @@
 virtual ~SwTable();
 
 // @@@ public copy ctor, but no copy assignment?
-SwTable( const SwTable rTable );   // kein Copy der Lines !!
+SwTable( const SwTable rTable );   // no copy of the lines !!
 private:
 // @@@ public copy ctor, but no copy assignment?
 SwTable  operator= (const SwTable );

-- 
To view, visit https://gerrit.libreoffice.org/2087
To unsubscribe, visit https://gerrit.libreoffice.org/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: Id40b6528515a9ebcf3deb0f84597955723118a15
Gerrit-PatchSet: 1
Gerrit-Project: core
Gerrit-Branch: master
Gerrit-Owner: Matthias Freund matti...@yahoo.de
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[PATCH] Comment translation german - english

2013-02-11 Thread Matthias Freund (via Code Review)
Hi,

I have submitted a patch for review:

https://gerrit.libreoffice.org/2088

To pull it, you can do:

git pull ssh://gerrit.libreoffice.org:29418/core refs/changes/88/2088/1

Comment translation german - english

I moved order so git grep '\\(der\|die\|das\)\' sw does not show up this 
file because of der

Change-Id: I98086993cf672806d763520b04e7693c8c772502
---
M sw/inc/swtypes.hxx
1 file changed, 2 insertions(+), 2 deletions(-)



diff --git a/sw/inc/swtypes.hxx b/sw/inc/swtypes.hxx
index ad99ac8..1ea929e 100644
--- a/sw/inc/swtypes.hxx
+++ b/sw/inc/swtypes.hxx
@@ -283,8 +283,8 @@
 // for it and sends a PREP_WIDOWS to its 
predecessor
 // (Master/Follow).
 PREP_QUOVADIS,  // If a footnote has to be split between two 
paragraphs
-// the last on the page has to receive a QUOVADIS 
in or-
-// der to format the text into it.
+// the last on the page has to receive a QUOVADIS 
in
+// order to format the text into it.
 PREP_BOSS_CHGD, // If a Frm changes its column/page this additional
 // Prepare is sended to POS_CHGD in MoveFwd/Bwd
 // (join Ftn-numbers etc.)

-- 
To view, visit https://gerrit.libreoffice.org/2088
To unsubscribe, visit https://gerrit.libreoffice.org/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: I98086993cf672806d763520b04e7693c8c772502
Gerrit-PatchSet: 1
Gerrit-Project: core
Gerrit-Branch: master
Gerrit-Owner: Matthias Freund matti...@yahoo.de
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[PATCH] Comment translation german - english

2013-02-11 Thread Matthias Freund (via Code Review)
Hi,

I have submitted a patch for review:

https://gerrit.libreoffice.org/2089

To pull it, you can do:

git pull ssh://gerrit.libreoffice.org:29418/core refs/changes/89/2089/1

Comment translation german - english

Change-Id: Ifc4be6a2253eaf89c996c0c2619b6d71e2fb5b5c
---
M sw/source/core/attr/hints.cxx
1 file changed, 3 insertions(+), 3 deletions(-)



diff --git a/sw/source/core/attr/hints.cxx b/sw/source/core/attr/hints.cxx
index cd895eb..1db49a4 100644
--- a/sw/source/core/attr/hints.cxx
+++ b/sw/source/core/attr/hints.cxx
@@ -108,7 +108,7 @@
 #ifdef DBG_UTIL
 void SwAttrSetChg::ClearItem( sal_uInt16 nWhch )
 {
-OSL_ENSURE( bDelSet, der Set darf nicht veraendert werden! );
+OSL_ENSURE( bDelSet, The Set may not be changed! );
 pChgSet-ClearItem( nWhch );
 }
 #endif
@@ -121,13 +121,13 @@
 // Overhead of SfxPoolItem
 int SwMsgPoolItem::operator==( const SfxPoolItem ) const
 {
-OSL_FAIL( SwMsgPoolItem kennt kein == );
+OSL_FAIL( SwMsgPoolItem knows no == );
 return 0;
 }
 
 SfxPoolItem* SwMsgPoolItem::Clone( SfxItemPool* ) const
 {
-OSL_FAIL( SwMsgPoolItem kennt kein Clone );
+OSL_FAIL( SwMsgPoolItem knows no Clone );
 return 0;
 }
 

-- 
To view, visit https://gerrit.libreoffice.org/2089
To unsubscribe, visit https://gerrit.libreoffice.org/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: Ifc4be6a2253eaf89c996c0c2619b6d71e2fb5b5c
Gerrit-PatchSet: 1
Gerrit-Project: core
Gerrit-Branch: master
Gerrit-Owner: Matthias Freund matti...@yahoo.de
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[PATCH] Comment translation german - english

2013-02-11 Thread Matthias Freund (via Code Review)
Hi,

I have submitted a patch for review:

https://gerrit.libreoffice.org/2092

To pull it, you can do:

git pull ssh://gerrit.libreoffice.org:29418/core refs/changes/92/2092/1

Comment translation german - english

Change-Id: I76c5124ff13abe4610b8cc9a07ba75e038c02e8b
---
M sw/source/core/crsr/crsrsh.cxx
M sw/source/core/crsr/pam.cxx
M sw/source/core/doc/doc.cxx
M sw/source/core/doc/doccomp.cxx
M sw/source/core/doc/doccorr.cxx
M sw/source/core/doc/docdraw.cxx
M sw/source/core/doc/tblrwcl.cxx
7 files changed, 12 insertions(+), 12 deletions(-)



diff --git a/sw/source/core/crsr/crsrsh.cxx b/sw/source/core/crsr/crsrsh.cxx
index a87677f..e417c92 100644
--- a/sw/source/core/crsr/crsrsh.cxx
+++ b/sw/source/core/crsr/crsrsh.cxx
@@ -2017,7 +2017,7 @@
 if( !bBasicHideCrsr )
 {
 bSVCrsrVis = sal_False;
-// evt. die sel. Bereiche aufheben !!
+// possibly reverse selected areas!!
 SET_CURR_SHELL( this );
 pVisCrsr-Hide();
 }
@@ -2529,7 +2529,7 @@
 SwNodes rNds = rDoc.GetNodes();
 
 SwNodeIndex aNodeIdx( *rNds.GetEndOfContent().StartOfSectionNode() );
-SwCntntNode* pCNd = rNds.GoNext( aNodeIdx ); // gehe zum 1. ContentNode
+SwCntntNode* pCNd = rNds.GoNext( aNodeIdx ); // go to the first 
ContentNode
 
 pCurCrsr = new SwShellCrsr( *this, SwPosition( aNodeIdx, SwIndex( pCNd, 0 
)));
 
diff --git a/sw/source/core/crsr/pam.cxx b/sw/source/core/crsr/pam.cxx
index 505477a..741679e 100644
--- a/sw/source/core/crsr/pam.cxx
+++ b/sw/source/core/crsr/pam.cxx
@@ -667,7 +667,7 @@
 if( pFmt-GetProtect().IsCntntProtected() )
 {
 const SwFmtCntnt rCntnt = pFmt-GetCntnt(sal_False);
-OSL_ENSURE( rCntnt.GetCntntIdx(), wo ist der 
SectionNode? );
+OSL_ENSURE( rCntnt.GetCntntIdx(), where is the 
SectionNode? );
 sal_uLong nIdx = rCntnt.GetCntntIdx()-GetIndex();
 if( nSttIdx = nIdx  nEndIdx = nIdx 
 
rCntnt.GetCntntIdx()-GetNode().GetNodes().IsDocNodes() )
diff --git a/sw/source/core/doc/doc.cxx b/sw/source/core/doc/doc.cxx
index 80cfa84..993eefc 100644
--- a/sw/source/core/doc/doc.cxx
+++ b/sw/source/core/doc/doc.cxx
@@ -1221,7 +1221,7 @@
 bool bHasPostIts = false;
 
 SwFieldType* pFldType = pIDFA-GetSysFldType( RES_POSTITFLD );
-OSL_ENSURE( pFldType, kein PostItType ? );
+OSL_ENSURE( pFldType, no PostItType ? );
 
 if( pFldType-GetDepends() )
 {
@@ -1575,7 +1575,7 @@
 sal_Int32 i = 0;
 for ( i = 1; pStPage  i  nDocPageCount; ++i )
 pStPage = (SwPageFrm*)pStPage-GetNext();
-if ( !pStPage )  // dann wars das
+if ( !pStPage )  // Then it was that
 return;
 
 // currently for prospect printing all pages are valid to be printed
@@ -2486,7 +2486,7 @@
 return mbLinksUpdated;
 }
 
-// embedded alle lokalen Links (Bereiche/Grafiken)
+// embedded all local links (Areas/Graphics)
 static ::sfx2::SvBaseLink* lcl_FindNextRemovableLink( const 
::sfx2::SvBaseLinks rLinks, sfx2::LinkManager rLnkMgr )
 {
 for( sal_uInt16 n = 0; n  rLinks.size(); ++n )
diff --git a/sw/source/core/doc/doccomp.cxx b/sw/source/core/doc/doccomp.cxx
index 594b03b..0df87ac 100644
--- a/sw/source/core/doc/doccomp.cxx
+++ b/sw/source/core/doc/doccomp.cxx
@@ -497,7 +497,7 @@
 for( size_t n = 0; n  rData.GetLineCount(); ++n )
 {
 const CompareLine* pLine = rData.GetLine( n );
-OSL_ENSURE( pLine, wo ist die Line? );
+OSL_ENSURE( pLine, where is the line? );
 sal_uLong nH = pLine-GetHashValue();
 
 sal_uLong* pFound = pHashArr[ nH % nPrime ];
diff --git a/sw/source/core/doc/doccorr.cxx b/sw/source/core/doc/doccorr.cxx
index 2379c71..50868ea 100644
--- a/sw/source/core/doc/doccorr.cxx
+++ b/sw/source/core/doc/doccorr.cxx
@@ -319,7 +319,7 @@
 SwPosition aNewPos(rNewPos);
 for( sal_uInt16 n = 0; n  rTbl.size(); ++n )
 {
-// liegt auf der Position ??
+// lies on the position ??
 lcl_PaMCorrRel1( rTbl[ n ], rOldNode.GetNode(), aNewPos, 
aNewPos.nContent.GetIndex() + nOffset );
 }
 }
diff --git a/sw/source/core/doc/docdraw.cxx b/sw/source/core/doc/docdraw.cxx
index 25a5a4e..c8d9ed3 100644
--- a/sw/source/core/doc/docdraw.cxx
+++ b/sw/source/core/doc/docdraw.cxx
@@ -523,7 +523,7 @@
 nOrdNum = pContact-GetMaster()-GetOrdNum();
 }
 else {
-OSL_ENSURE( !this, was ist das fuer ein Format? );
+OSL_ENSURE( !this, what is that for a format? );
 }
 }
 
diff --git a/sw/source/core/doc/tblrwcl.cxx b/sw/source/core/doc/tblrwcl.cxx
index 9818bde..3635be5 100644
--- a/sw/source/core/doc/tblrwcl.cxx
+++ b/sw/source/core/doc/tblrwcl.cxx
@@ -1214,7 +1214,7 @@
 for (size_t n = 0; n  aSelBoxes.size(); ++n)
 {
 SwTableBox* pSelBox = aSelBoxes[n];
-

Re: [PATCH] Comment translation german - english

2013-02-11 Thread Riccardo Magliocchetti

Hello,

Il 10/02/2013 01:27, Matthias Freund (via Code Review) ha scritto:

Change-Id: If10593f81d4b2a00b8305e955ca7e6a15ed47aff
---
M sw/source/ui/table/tablepg.hxx
1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/sw/source/ui/uno/unotxdoc.cxx b/sw/source/ui/uno/unotxdoc.cxx
index ce295e9..02d8ae7 100644
--- a/sw/source/ui/uno/unotxdoc.cxx
+++ b/sw/source/ui/uno/unotxdoc.cxx
@@ -733,7 +733,7 @@
 SwDocPositions eStart = pSearch-bBack ? DOCPOS_END : DOCPOS_START;
 SwDocPositions eEnd = pSearch-bBack ? DOCPOS_START : DOCPOS_END;
 
-// Suche soll ueberall stattfinden
+// Search should take place anywhere
 pUnoCrsr-SetRemainInSection(sal_False);
 sal_uInt32 nResult;
 UnoActionContext aContext(pDocShell-GetDoc());
@@ -793,9 +793,8 @@
 
 }
 
-/* --
- * wird fuer findAll/First/Next verwendet
- * --*/
+// Used for findAll/First/Next
+
 SwUnoCrsr*  SwXTextDocument::FindAny(const Reference util::XSearchDescriptor 
  xDesc,
 Reference XTextCursor   xCrsr, 
sal_Bool bAll,
 sal_Int32 nResult,
@@ -853,18 +852,18 @@
 util::SearchOptions aSearchOpt;
 pSearch-FillSearchOptions( aSearchOpt );
 
 /*
  * folgende Kombinationen sind erlaubt:
  *  - suche einen im Body:  - FND_IN_BODY
  *  - suche alle im Body:   - FND_IN_BODYONLY | FND_IN_SELALL
  *  - suche in Selectionen: einen / alle- FND_IN_SEL  [ | FND_IN_SELALL ]
  *  - suche im nicht Body: einen / alle - FND_IN_OTHER [ | FND_IN_SELALL ]
  *  - suche ueberall alle:  - FND_IN_SELALL
  */
 int eRanges(FND_IN_BODY);
 if(bParentInExtra)
 eRanges = FND_IN_OTHER;
-if(bAll) //immer - ueberall?
+if(bAll) //always - everywhere?
 eRanges = FND_IN_SELALL;
 SwDocPositions eStart = !bAll ? DOCPOS_CURR : pSearch-bBack ? DOCPOS_END 
: DOCPOS_START;
 SwDocPositions eEnd = pSearch-bBack ? DOCPOS_START : DOCPOS_END;
@@ -1070,7 +1069,8 @@
 if(IsValid())
 {
 SwPagePreViewPrtData aData;
-//falls nur einige Properties kommen, dann die akt. Einstellungen 
benutzen
+//if only a few properties are coming, then use the current settings
+falls nur einige Properties kommen, dann die akt. Einstellungen benutzen
 const SwPagePreViewPrtData* pData = 
pDocShell-GetDoc()-GetPreViewPrtData();
 if(pData)
 aData = *pData;
@@ -1213,7 +1213,7 @@
 // #i117783#
 bApplyPagePrintSettingsFromXPagePrintable = sal_True;
 pFrame-GetViewShell()-ExecuteSlot(aReq);
-// Frame schliessen
+// Frame close
 pFrame-DoClose();
 
 }
@@ -1428,7 +1428,7 @@
 
 voidSwXTextDocument::InitNewDoc()
 {
-// zunaechst alle Collections invalidieren, dann Referenzen loeschen und 
Null setzen
+// first invalidate all collections, then delete references and Set to zero
 if(pxXTextTables)
 {
  XNameAccess* pTbls = pxXTextTables-get();
@@ -1717,7 +1717,7 @@
 {
 aTmpServiceName = 
OUString(RTL_CONSTASCII_USTRINGPARAM(com.sun.star.drawing.OLE2Shape));
 }
-//hier den Draw - Service suchen
+//here search for the draw service
 Reference XInterface   xTmp = 
SvxFmMSFactory::createInstance(aTmpServiceName);
 if(bShape)
 {
@@ -1744,8 +1744,8 @@
 throw( Exception, RuntimeException )
 {
 Reference XInterface   xInt = createInstance(ServiceSpecifier);
-//die Any-Sequence dient zur Initialisierung von Objekten, die auf
-//Parameter zwingend angewiesen sind - bis jetzt haben wir das nicht
+// The Any-Sequence is for initializing objects that are dependent
+// on parameters necessarily - so far we have not.
 return xInt;
 }
 
@@ -3137,9 +3137,9 @@
 SwXTextDocumentBaseClass::operator delete(p);
 }
 
-/*---
-retrieve languages already used in current document
--*/
+/**
+ * retrieve languages already used in current document
+ */
 uno::Sequence lang::Locale  SAL_CALL SwXTextDocument::getDocumentLanguages(
 ::sal_Int16 nScriptTypes,
   

[PATCH] Comment translation - german-english - 3 files

2013-02-15 Thread Matthias Freund (via Code Review)
Hi,

I have submitted a patch for review:

https://gerrit.libreoffice.org/2157

To pull it, you can do:

git pull ssh://gerrit.libreoffice.org:29418/core refs/changes/57/2157/1

Comment translation - german-english - 3 files

I'm struggeling over line 407 in sw/source/core/edit/acorrect.cxx, is this the 
right translation.
Is this a question or is it a description what happens in the moment???

Change-Id: Ie665a8dffc41ee057c0277788282eea96cbbe6a3
---
@@ -853,18 +852,18 @@
 pSearch-FillSearchOptions( aSearchOpt );
 
-/*
- * folgende Kombinationen sind erlaubt:
- *  - suche einen im Body:  - FND_IN_BODY
- *  - suche alle im Body:   - FND_IN_BODYONLY | FND_IN_SELALL
- *  - suche in Selectionen: einen / alle- FND_IN_SEL  [ | FND_IN_SELALL ]
- *  - suche im nicht Body: einen / alle - FND_IN_OTHER [ | FND_IN_SELALL ]
- *  - suche ueberall alle:  - FND_IN_SELALL
+/**
+ * The following combinations are allowed:
+ *  - Search in the body:   - FND_IN_BODY
+ *  - Search all in the body:   - FND_IN_BODYONLY | FND_IN_SELALL
+ *  - Search in selections: one / all   - FND_IN_SEL  [ | FND_IN_SELALL ]
+ *  - Search outside the body: one / all- FND_IN_OTHER [ | FND_IN_SELALL ]
+ *  - Search everywhere all:- FND_IN_SELALL
  */
 int eRanges(FND_IN_BODY);
M sw/source/core/docnode/ndtbl.cxx
M sw/source/core/edit/acorrect.cxx
M sw/source/ui/utlui/numfmtlb.cxx
3 files changed, 41 insertions(+), 41 deletions(-)



diff --git a/sw/source/ui/table/tablepg.hxx b/sw/source/ui/table/tablepg.hxx
@@ -110,8 +110,8 @@
  SwTwips nMinWidth;
  sal_uInt16  nNoOfCols;
  sal_uInt16  nNoOfVisibleCols;
-//Breite merken, wenn auf autom. Ausrichtung gestellt wird
-sal_uInt16  aValueTbl[MET_FIELDS];//primaere Zuordnung der 
MetricFields
+//Remember the with, when switching to autoalign

  ^
  --- this looks like a typo, should this be width?

thanks,
riccardo
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


Re: [PATCH] Comment translation german - english

2013-02-11 Thread Jan Holesovsky
Hi Matthias,

Matthias Freund (via Code Review) píše v Ne 10. 02. 2013 v 19:37 +:

 Comment translation german - english

Thank you a lot for your comment translations!  Please don't hesitate to
pack more translations into one commit, for comment translations it is
not necessary to keep the changes small / local [as it is preferred for
code changes, where there is some probability that the change might need
to be reverted] - ie. it is just OK to translate several files [3-10 of
them], and push them all as one commit.

Keep up the great work :-)

Thank you,
Kendy

___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice